from ipapython import ipautil
from ipapython.platform import base

class DebianAuthConfig(base.AuthConfig):
    """
    Debian implementation of the AuthConfig class.

    Debian doesn't provide a single application for changing both
    nss and pam configuration. PAM can be configured using debconf but there
    is currently no such solution for updating NSS database and every package
    does it by itself.

    We'll have to play a catch-up game with the rest of the FreeIPA project
    filtering out .enable() and .disable() calls that are useless for us,
    and making the best out of the rest of them.
    """

    def __build_args(self):
        args = ['--force',  '--package']
        for (option, value) in self.parameters.items():
            if option == "sssdauth":
                option = "sss"
            if type(value) is bool and not value:
               if not any("remove" in s for s in args):
                    args.append("--remove")
               args.append("%s" % (option))
        return args

    def execute(self):
        env = {"DEBCONF_FRONTEND" : "noninteractive"}
        args = self.__build_args()
        ipautil.run(["/usr/sbin/pam-auth-update"] + args, env = env)

